| Title: | Complete Text of the Qur'an |
|---|---|
| Description: | Full text, in data frames containing one row per verse, of the Qur'an in Arabic (with and without vowels) and in English (the Yusuf Ali and Saheeh International translations), formatted to be convenient for text analysis. |
| Authors: | Andrew Heiss [aut, cre] |
| Maintainer: | Andrew Heiss <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-05-25 09:59:14 UTC |
| Source: | https://github.com/andrewheiss/quran |
This package contains the complete text of the Qur'an in Arabic (with and without vowels) and in English (the Yusuf Ali and Saheeh International translations), formatted to be convenient for text analysis.
A dataset containing the Arabic text of the Qur'an, with vowels.
quran_arquran_ar
A data frame with 6236 rows and 18 columns:
surah_idUnique id number for the surah
ayah_idUnique id number for the ayah
surah_title_arName of the surah (Arabic)
surah_title_enName of the surah (English; transliterated)
surah_title_en_transName of the surah (English; translated)
revelation_typeType of the surah (Meccan or Medinan)
textAyah text
surahSurah
ayahAyah
ayah_titleCombined surah and ayah (e.g. 2:242)
juzJuz'
manzilManzil
pagePage number
hizb_quarterMaqra
sajdaBinary indicator for presence of a sajdah
sajda_idUnique id number for the sajdah
sajda_recommendedBinary indicator for whether a sajdah is recommended
sajda_obligatoryBinary indicator for whether a sajdah is obligatory
Because Surahs 89 and 113 are both translated as "The Dawn," Surah 113 has been retitled "The Daybreak"
Tanzil (http://tanzil.net/docs/download) and Al Quran Cloud (https://alquran.cloud/)
# See first few rows head(quran_ar) # How many ayahs are in each surah? library(dplyr) quran_ar %>% group_by(surah_title_ar) %>% summarize(total_ayaat = n())# See first few rows head(quran_ar) # How many ayahs are in each surah? library(dplyr) quran_ar %>% group_by(surah_title_ar) %>% summarize(total_ayaat = n())
A dataset containing the Arabic text of the Qur'an, without vowels.
quran_ar_minquran_ar_min
A data frame with 6236 rows and 18 columns:
surah_idUnique id number for the surah
ayah_idUnique id number for the ayah
surah_title_arName of the surah (Arabic)
surah_title_enName of the surah (English; transliterated)
surah_title_en_transName of the surah (English; translated)
revelation_typeType of the surah (Meccan or Medinan)
textAyah text
surahSurah
ayahAyah
ayah_titleCombined surah and ayah (e.g. 2:242)
juzJuz'
manzilManzil
pagePage number
hizb_quarterMaqra
sajdaBinary indicator for presence of a sajdah
sajda_idUnique id number for the sajdah
sajda_recommendedBinary indicator for whether a sajdah is recommended
sajda_obligatoryBinary indicator for whether a sajdah is obligatory
Because Surahs 89 and 113 are both translated as "The Dawn," Surah 113 has been retitled "The Daybreak"
Tanzil (http://tanzil.net/docs/download) and Al Quran Cloud (https://alquran.cloud/)
# See first few rows head(quran_ar_min) # How many ayahs are in each surah? library(dplyr) quran_ar_min %>% group_by(surah_title_ar) %>% summarize(total_ayaat = n())# See first few rows head(quran_ar_min) # How many ayahs are in each surah? library(dplyr) quran_ar_min %>% group_by(surah_title_ar) %>% summarize(total_ayaat = n())
A dataset containing the English text of the Saheeh International translation of the Qur'an.
quran_en_sahihquran_en_sahih
A data frame with 6236 rows and 18 columns:
surah_idUnique id number for the surah
ayah_idUnique id number for the ayah
surah_title_arName of the surah (Arabic)
surah_title_enName of the surah (English; transliterated)
surah_title_en_transName of the surah (English; translated)
revelation_typeType of the surah (Meccan or Medinan)
textAyah text
surahSurah
ayahAyah
ayah_titleCombined surah and ayah (e.g. 2:242)
juzJuz'
manzilManzil
pagePage number
hizb_quarterMaqra
sajdaBinary indicator for presence of a sajdah
sajda_idUnique id number for the sajdah
sajda_recommendedBinary indicator for whether a sajdah is recommended
sajda_obligatoryBinary indicator for whether a sajdah is obligatory
Because Surahs 89 and 113 are both translated as "The Dawn," Surah 113 has been retitled "The Daybreak"
Tanzil (http://tanzil.net/docs/download) and Al Quran Cloud (https://alquran.cloud/)
# See first few rows head(quran_en_sahih) # How many ayahs are in each surah? library(dplyr) quran_en_sahih %>% group_by(surah_title_en) %>% summarize(total_ayaat = n())# See first few rows head(quran_en_sahih) # How many ayahs are in each surah? library(dplyr) quran_en_sahih %>% group_by(surah_title_en) %>% summarize(total_ayaat = n())
A dataset containing the English text of the Yusuf Ali translation of the Qur'an.
quran_en_yusufaliquran_en_yusufali
A data frame with 6236 rows and 18 columns:
surah_idUnique id number for the surah
ayah_idUnique id number for the ayah
surah_title_arName of the surah (Arabic)
surah_title_enName of the surah (English; transliterated)
surah_title_en_transName of the surah (English; translated)
revelation_typeType of the surah (Meccan or Medinan)
textAyah text
surahSurah
ayahAyah
ayah_titleCombined surah and ayah (e.g. 2:242)
juzJuz'
manzilManzil
pagePage number
hizb_quarterMaqra
sajdaBinary indicator for presence of a sajdah
sajda_idUnique id number for the sajdah
sajda_recommendedBinary indicator for whether a sajdah is recommended
sajda_obligatoryBinary indicator for whether a sajdah is obligatory
Because Surahs 89 and 113 are both translated as "The Dawn," Surah 113 has been retitled "The Daybreak"
Tanzil (http://tanzil.net/docs/download) and Al Quran Cloud (https://alquran.cloud/)
# See first few rows head(quran_en_yusufali) # How many ayahs are in each surah? library(dplyr) quran_en_yusufali %>% group_by(surah_title_en) %>% summarize(total_ayaat = n())# See first few rows head(quran_en_yusufali) # How many ayahs are in each surah? library(dplyr) quran_en_yusufali %>% group_by(surah_title_en) %>% summarize(total_ayaat = n())